@@ -35,6 +35,8 @@ try:
     from bzrlib.plugins.gtk.merge import MergeDialog
     from bzrlib.plugins.gtk.push import PushDialog
     from bzrlib.plugins.gtk.status import StatusWindow
+    from bzrlib.plugins.gtk import set_ui_factory
+    set_ui_factory()
     HAS_BZR_GTK = True
 except ImportError:
     HAS_BZR_GTK = False
@@ -209,7 +211,11 @@ class BzrProject(ControllerMixin):
         if not HAS_BZR_GTK:
             return
         from bzrlib.plugins.gtk.missing import MissingWindow
-        parent_location = self.working_tree.branch.get_parent()
+        try:
+            parent_location = self.working_tree.branch.get_parent()
+            parent_branch = Branch.open_containing(parent_location)[0]
+        except NotBranchError:
+            parent_location = None
         if parent_location is None:
             message = _("Nothing to do; this branch does not have a parent.")
             dialog = Gtk.MessageDialog(
@@ -218,7 +224,6 @@ class BzrProject(ControllerMixin):
             dialog.run()
             dialog.destroy()
             return
-        parent_branch = Branch.open_containing(parent_location)[0]
         self.working_tree.branch.lock_read()
         try:
             parent_branch.lock_read()
