@@ -247,8 +247,13 @@ class Finder(ControllerMixin):
     def ui_callbacks(self):
         """The dict of callbacks for the ui widgets."""
         return {
+            'on_choose_directory_icon_press':
+                self.on_choose_directory_icon_press,
             'on_find_in_files': self.on_find_in_files,
+            'on_find_in_files_icon_press': self.on_find_in_files_icon_press,
             'on_replace_in_files': self.on_replace_in_files,
+            'on_replace_in_files_icon_press':
+                self.on_replace_in_files_icon_press,
             'on_save_results': self.on_save_results,
             }
 
@@ -272,7 +277,8 @@ class Finder(ControllerMixin):
             path_ = '.'
         elif path_ == self.CURRENT_FILE:
             document = self.active_document
-            path_ = os.path.dirname(document.get_uri_for_display())
+            path_ = document.get_uri_for_display().replace('file://', '')
+            path_ = os.path.dirname(path_)
         return path_
 
     @property
@@ -323,11 +329,31 @@ class Finder(ControllerMixin):
             self.widgets.get_object('match_case_checkbox').get_active(),
             self.file_pattern)
 
+    def on_choose_directory_icon_press(self, widget, position, event):
+        """Choose a directory using a dialog."""
+        dialog = Gtk.FileChooserDialog(
+            title="Choose a directory to find in", parent=self.window,
+            action=Gtk.FileChooserAction.SELECT_FOLDER,
+            buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                     Gtk.STOCK_OPEN, Gtk.ResponseType.ACCEPT))
+        dialog.set_current_folder(os.getcwd())
+        if dialog.run() == Gtk.ResponseType.ACCEPT:
+            path = dialog.get_filename()
+            if path:
+                self.path_comboentry.get_child().set_text(path)
+        dialog.destroy()
+
     def on_find_in_files(self, widget=None, substitution=None):
         """Find and present the matches."""
         treestore = self.file_lines_view.get_model()
         treestore.clear()
         find_params = self.get_find_params()
+        if (find_params.path != self.CURRENT_FILE
+            and not os.path.exists(find_params.path)):
+            message = 'The directory path does not exist!'
+            self.file_lines_view.get_model().append(
+                    None, (message, 'stock_dialog-info', 0, None, None))
+            return
         self.last_find = find_params
         pattern = find_params.pattern
         self.save_find_data()
@@ -339,6 +365,10 @@ class Finder(ControllerMixin):
         # of this method.
         GObject.idle_add(find_worker.start)
 
+    def on_find_in_files_icon_press(self, widget, position, event):
+        """Handle find pattern entry icon-press event."""
+        self.on_find_in_files()
+
     def on_find_complete(self):
         if self.path_comboentry.get_active_text() == self.CURRENT_FILE:
             self.file_lines_view.expand_all()
@@ -394,6 +424,10 @@ class Finder(ControllerMixin):
         elif response == Gtk.ResponseType.ACCEPT:
             self.on_find_in_files(substitution=substitution)
 
+    def on_replace_in_files_icon_press(self, widget, position, event):
+        """Handle replace pattern entry icon-press event."""
+        self.on_replace_in_files()
+
     def on_save_results(self, widget=None):
         """Save the search results to a file."""
         dialog = Gtk.FileChooserDialog(
