@@ -12,9 +12,11 @@ import os
 import re
 from tempfile import NamedTemporaryFile
 from textwrap import wrap
+import threading
 
 from gi.repository import (
     Gio,
+    GObject,
     Gtk,
     )
 
@@ -44,6 +46,67 @@ class FilteredReporter(Reporter):
         # Suppress the set behaviour because the config controls the rules.
         pass
 
+    def _message_file_lines(self, line_no, message, icon=None,
+                            base_dir=None, file_name=None):
+        """Queue the messages in the file_lines_view."""
+        if self.piter is None:
+            mime_type = 'gnome-mime-text'
+            # Do not queue this call because the piter must be known now
+            # for all subsequent appends to work.
+            self.piter = self.treestore.append(
+                None, (file_name, mime_type, 0, None, base_dir))
+        self.idle_append_issue(
+            self.piter, file_name, icon, line_no, message, base_dir)
+
+    def append_issue(self, piter, file_path, icon, lineno, text, path):
+        self.treestore.append(piter, (file_path, icon, lineno, text, path))
+        return False
+
+    def idle_append_issue(self, piter, file_path, icon, lineno, text, path):
+        GObject.idle_add(
+            self.append_issue, piter, file_path, icon, lineno, text, path)
+
+
+class CheckerWorker(threading.Thread):
+
+    def __init__(self, documents, reporter, callback, quiet):
+        super(CheckerWorker, self).__init__()
+        self.documents = documents
+        self.reporter = reporter
+        self.callback = callback
+        self.quiet = quiet
+        self.model = self.reporter.file_lines_view.get_model()
+
+    def _ensure_file_path(self, checker):
+        if os.path.isfile(checker.file_path):
+            return None
+        temp_file = NamedTemporaryFile(suffix='gdp', delete=False)
+        temp_file.write(checker.text)
+        temp_file.flush()
+        checker.file_path = temp_file.name
+        return temp_file
+
+    def start(self):
+        super(CheckerWorker, self).start()
+        return False
+
+    def run(self):
+        for document in self.documents:
+            file_path = document.get_uri_for_display()
+            text = document.props.text
+            language = Language.get_language(file_path)
+            self.reporter.piter = None
+            checker = UniversalChecker(
+                file_path, text=text, language=language,
+                reporter=self.reporter)
+            temp_file = self._ensure_file_path(checker)
+            try:
+                checker.check()
+            finally:
+                if temp_file:
+                    temp_file.unlink(temp_file.name)
+        self.callback(self.quiet)
+
 
 class Formatter(ControllerMixin):
     """Format Gedit Document and selection text."""
@@ -76,6 +139,10 @@ class Formatter(ControllerMixin):
         icon = Gtk.Image.new_from_stock(Gtk.STOCK_INFO, Gtk.IconSize.MENU)
         panel.add_item(
             self.file_lines, 'gdpformat', 'Check syntax and style', icon)
+        self.reporter = FilteredReporter(
+            Reporter.FILE_LINES, treeview=self.file_lines_view)
+        self.checker_id = None
+        self.checker_worker = None
 
     def deactivate(self):
         """Clean up resources before deactivation."""
@@ -304,54 +371,48 @@ class Formatter(ControllerMixin):
         """Reformat the doctest."""
         bounds, text = self._get_bounded_text()
         file_name = self.active_document.get_uri_for_display()
-        reviewer = DoctestReviewer(text, file_name)
+        reviewer = DoctestReviewer(file_name, text)
         new_text = reviewer.format()
         self._put_bounded_text(bounds, new_text)
 
-    def _ensure_file_path(self, checker):
-        if os.path.isfile(checker.file_path):
-            return None
-        temp_file = NamedTemporaryFile(suffix='gdp', delete=False)
-        temp_file.write(checker.text)
-        temp_file.flush()
-        checker.file_path = temp_file.name
-        return temp_file
-
-    def _check_style(self, document):
-        """Check the style and syntax of a document."""
-        file_path = document.get_uri_for_display()
-        start_iter = document.get_start_iter()
-        end_iter = document.get_end_iter()
-        text = document.get_text(start_iter, end_iter, True)
-        reporter = FilteredReporter(
-            Reporter.FILE_LINES, treeview=self.file_lines_view)
-        language = Language.get_language(file_path)
-        checker = UniversalChecker(
-            file_path, text=text, language=language, reporter=reporter)
-        temp_file = self._ensure_file_path(checker)
-        try:
-            checker.check()
-        finally:
-            if temp_file:
-                temp_file.unlink(temp_file.name)
-
     def check_style(self, action, documents=None, quiet=False):
         """Check the style and syntax of the active document."""
+        if self.checker_id is not None:
+            return
+        if self.checker_worker is not None and self.checker_worker.is_alive():
+            # This is not as reliable to Gtk's idle handle. Maybe this
+            # sould call join() to wait tot the process to terminate.
+            return
         self.file_lines_view.get_model().clear()
         if documents is None:
             documents = [self.active_document]
-        for document in documents:
-            self._check_style(document)
+        self.checker_worker = CheckerWorker(
+            documents, self.reporter, self.on_check_style_complete, quiet)
+        # Queue the find worker after the events emited at the top
+        # of this method.
+        self.checker_id = GObject.idle_add(self.checker_worker.start)
+
+    def on_check_style_complete(self, quiet):
+        # Gracefully end the operation in the main_loop.
+        GObject.idle_add(self.do_check_style_complete, quiet)
+
+    def do_check_style_complete(self, quiet):
+        self.checker_worker = None
+        self.checker_id = None
         model = self.file_lines_view.get_model()
         first = model.get_iter_first()
         if first is None:
+            # Noted that the mesage is in the file_path position.
             model.append(
                 None, ('No problems found', 'emblem-default', 0, None, None))
-        if first is None and quiet:
-            # Do not interupt the user to say there is nothing to see.
-            return
         self.file_lines_view.expand_all()
-        self.show()
+        if first is not None or not quiet:
+            self.show()
+        return False
+
+    def check_style_background(self, action, documents=None):
+        """Check the style in the background."""
+        self.check_style(action, quiet=True)
 
     def check_all_style(self, action):
         """Check the style and syntax of all open documents."""
