@@ -3,6 +3,8 @@
 
 __metaclass__ = type
 
+from gi.repository import Gtk
+
 from bzrlib.errors import (
     NotBranchError,
     )
@@ -10,7 +12,10 @@ from bzrlib.errors import (
 from gdp.bzr import (
     BzrProject,
     )
-from testing import GeditTestCase
+from testing import (
+    GeditTestCase,
+    MockMethod,
+    )
 
 
 class FakeBranch:
@@ -49,3 +54,12 @@ class BzrTestCase(GeditTestCase):
         self.assertEqual(
             'This branch does not have a push location.',
             bzr_project._message)
+
+    def test_missing_no_parent(self):
+        text_file = self.make_file('hello')
+        window, view, document = self.make_gedit(text_file.name)
+        bzr_project = BzrProject(window)
+        bzr_project.working_tree = FakeTree()
+        MockMethod.bind(self, Gtk.MessageDialog, 'run')
+        bzr_project.show_missing(None)
+        self.assertEqual(1, Gtk.MessageDialog.run.called)
