@@ -276,6 +276,32 @@ class PythonGeneratorTestCase(GeditTestCase):
             ['while'],
             [proposal._word for proposal in sorted(proposals)])
 
+    def test_get_words_gtk_module(self):
+        python_file = self.make_file('\n'.join([
+            'from gi.repository import Gtk',
+            'justification = Gtk.Justification.',
+            ]))
+        window, view, document = self.make_gedit(python_file.name)
+        document.place_cursor(document.get_end_iter())
+        generator = PythonGenerator(document)
+        is_authoritative, proposals = generator.get_words()
+        self.assertEqual(
+            ['CENTER', 'FILL', 'LEFT', 'RIGHT'],
+            [proposal._word for proposal in sorted(proposals)][0:4])
+
+    def test_get_words_python_module(self):
+        python_file = self.make_file('\n'.join([
+            'import os.path',
+            'dirname = os.path.',
+            ]))
+        window, view, document = self.make_gedit(python_file.name)
+        document.place_cursor(document.get_end_iter())
+        generator = PythonGenerator(document)
+        is_authoritative, proposals = generator.get_words('a')
+        self.assertEqual(
+            ['abspath', 'altsep'],
+            [proposal._word for proposal in sorted(proposals)])
+
     def test_get_words_is_authoratative(self):
         # The matches are authoritative when a namespace is
         # matched without a prefix.
