@@ -93,6 +93,12 @@ class GDPPluginMixin:
             return
         self.signal_ids[signal] = obj.connect(signal, method)
 
+    def connect_signal_after(self, obj, signal, method):
+        """Connect the signal from the provided object to a method."""
+        if obj is None:
+            return
+        self.signal_ids[signal] = obj.connect_after(signal, method)
+
     def disconnect_signal(self, obj, signal):
         """Disconnect the signal from the provided object."""
         if obj is None:
