@@ -152,15 +152,7 @@ class FormatPlugin(GDPPluginMixin, GObject.Object, Gedit.WindowActivatable):
         format_css_item = '/MenuBar/ToolsMenu/ToolsOps_2/ReformatCSS'
         manager.get_action(format_css_item).props.sensitive = (
             language_id == 'css')
-        self.connect_signal(
+        self.connect_signal_after(
             document, 'syntax-error-python', self.controller.check_style)
-        self.connect_signal(
-            document, 'saved', self.on_document_saved)
-
-    def on_document_saved(self, document, user_data):
-        """Callback method for `document-saved` document signal.
-
-        Automaticaly check syntax when file is saved.
-        """
-        if self.controller:
-            self.controller.check_style(None, None, True)
+        self.connect_signal_after(
+            document, 'saved', self.controller.check_style_background)
