@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# Copyright (C) 2007 - Curtis Hovey <sinzui.is at verizon.net>
+# Copyright (C) 2007-2012 - Curtis Hovey <sinzui.is at verizon.net>
 # This software is licensed under the GNU General Public License version 2
 # (see the file COPYING).
 """test.py configuration
@@ -10,15 +10,6 @@ Edit this file to setup the test environment. Do not alter
 test suite.
 """
 
-import os
-from gi.repository import (
-    GObject,
-    Gdk,
-    Pango,
-    Gtk,
-    GtkSource,
-    )
-
 # Add additional Python lib paths as needed.
 paths = [
     './plugins/',
