@@ -1,20 +1,22 @@
-# Copyright (C) 2007-2009 - Curtis Hovey <sinzui.is at verizon.net>
+# Copyright (C) 2007-2012 - Curtis Hovey <sinzui.is at verizon.net>
 # This software is licensed under the GNU General Public License version 2
 # (see the file COPYING).
 """A dummy implemetation of objects."""
 
-__metaclass__ = type
+from collections import defaultdict
 
-
-from testing import Dummy
+from mimetypes import MimeTypes
+from urllib import urlopen
 
 import __builtin__
 from gettext import gettext
 from gettext import gettext as _
+
 from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import GtkSource
 
+from testing import Dummy
 
 GEDIT_TAB_STATE_NORMAL = 'normal'
 GEDIT_TAB_STATE_LOADING = 'loading'
@@ -225,30 +227,6 @@ def gedit_window_get_type():
         raise NotImplementedError
 
 
-def get_language_manager():
-    """A dummy implementation of get_language_manager."""
-    if 'get_language_manager' in dummy:
-        return dummy['get_language_manager']
-    else:
-        raise NotImplementedError
-
-
-def language_manager_list_languages_sorted(lm, include_hidden):
-    """A dummy implementation of language_manager_list_languages_sorted."""
-    if 'language_manager_list_languages_sorted' in dummy:
-        return dummy['language_manager_list_languages_sorted']
-    else:
-        raise NotImplementedError
-
-
-def language_manager_get_language_from_mime_type(lm, mime_type):
-    """A dummy of language_manager_get_language_from_mime_type."""
-    if 'language_manager_get_language_from_mime_type' in dummy:
-        return dummy['language_manager_get_language_from_mime_type']
-    else:
-        raise NotImplementedError
-
-
 def app_get_default():
     """A fake implementation of app_get_default.
 
@@ -504,8 +482,6 @@ class Document(GtkSource.Buffer):
         key = '%s.load' % self.__class__.__name__
         if key in dummy:
             return
-        from mimetypes import MimeTypes
-        from urllib import urlopen
         if location:
             uri = location.get_uri()
         try:
@@ -520,29 +496,10 @@ class Document(GtkSource.Buffer):
         self.encoding = encoding
         mt = MimeTypes()
         mime_type, encoding = mt.guess_type(uri)
-        lang_id = self._mime_types.get(mime_type, None)
-
-        class Language:
-
-            def __init__(self, lang_id):
-                self.id = lang_id
-
-            def get_id(self):
-                return self.id
-
-        if lang_id is None:
-            language = None
-        else:
-            language = Language(lang_id)
+        lang_manager = GtkSource.LanguageManager.get_default()
+        language = lang_manager.guess_language(uri, mime_type)
         self.set_language(language)
 
-    def get_language(self):
-        """A fake implementation of get_language."""
-        key = '%s.get_language' % self.__class__.__name__
-        if key in dummy:
-            return dummy[key]
-        return self.language
-
     def get_uri_for_display(self):
         """A fake implementation of get_uri."""
         key = '%s.get_uri' % self.__class__.__name__
@@ -557,11 +514,12 @@ class Document(GtkSource.Buffer):
 
     def get_mime_type(self):
         """A fake implementation of get_mime_type."""
+        language = self.get_language()
         key = '%s.get_mime_type' % self.__class__.__name__
         if key in dummy:
             return dummy[key]
-        elif self.language:
-            mime_types = self.language.get_mime_types()
+        elif language:
+            mime_types = language.get_mime_types()
             if mime_types:
                 return mime_types[0]
         else:
@@ -569,31 +527,51 @@ class Document(GtkSource.Buffer):
             pass
         return 'text/plain'
 
-    def set_language(self, val):
-        """A fake implementation of set_language."""
-        key = '%s.set_language' % self.__class__.__name__
-        if key in dummy:
-            dummy[key] = val
-            return
-        self.language = val
-
     def __init__(self):
         """A fake initialization of gedit.Document."""
         GtkSource.Buffer.__init__(self)
         self.uri = None
         self.encoding = None
-        self.language = None
-        self._mime_types = {
-            'text/x-python': 'python',
-            'text/x-python-doctest': 'doctest',
-            'text/css': 'css',
-            'text/html': 'html',
-            'application/javascript': 'js',
-            'application/xml': 'xml',
-            'application/x-sh': 'sh',
-            'application/x-zope-configuation': 'xml',
-            'application/x-zope-page-template': 'html',
-            }
+
+
+GObject.signal_new(
+    'cursor-moved', Document, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+GObject.signal_new(
+    'load', Document, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+GObject.signal_new(
+    'loaded', Document, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+GObject.signal_new(
+    'loading', Document, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+GObject.signal_new(
+    'save', Document, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+GObject.signal_new(
+    'saved', Document, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+GObject.signal_new(
+    'saving', Document, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+GObject.signal_new(
+    'search-highlight-updated', Document, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
 
 
 class Panel(Gtk.VBox):
@@ -781,6 +759,11 @@ class Tab(Gtk.VBox):
         Gtk.VBox.__init__(self)
 
 
+GObject.signal_new(
+    'drop-uris', Tab, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
 class View(GtkSource.View):
     """A dummy/fake implementation of View."""
 
@@ -858,6 +841,52 @@ class View(GtkSource.View):
         GtkSource.View.__init__(self, buffer=document)
 
 
+GObject.signal_new(
+    'drop-uris', View, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+class FakeProps(object):
+
+    def __init__(self):
+        self._props = defaultdict(str)
+
+    def __getattr__(self, name):
+        if name in object.__dict__:
+            return object.__dict__[name]
+        else:
+            return self.__dict__['_props'][name]
+
+    def __setattribute__(self, name, value):
+        if name in object.__dict__:
+            object.__dict__[name] = value
+        else:
+            object.__dict__['_props'][name] = value
+
+
+class FakePanel(object):
+
+    props = FakeProps()
+
+    def __init__(self):
+        self.widget = None
+        self.label = None
+        self.icon = None
+
+    def add_item(self, widget, item_id, label, icon):
+        self.widget = widget
+        self.label = label
+        self.icon = icon
+
+    def remove_item(self, widget):
+        self.widget = None
+        self.label = None
+        self.icon = None
+
+    def activate_item(self, panel_tab):
+        pass
+
+
 class Window(Gtk.Window):
     """A dummy/fake implementation of Window."""
 
@@ -968,23 +997,6 @@ class Window(Gtk.Window):
     def get_side_panel(self):
         """A fake bottom panel."""
 
-        class FakePanel:
-
-            def __init__(self):
-                self.widget = None
-                self.label = None
-                self.icon = None
-
-            def add_item(self, widget, item_id, label, icon):
-                self.widget = widget
-                self.label = label
-                self.icon = icon
-
-            def remove_item(self, widget):
-                self.widget = None
-                self.label = None
-                self.icon = None
-
         return FakePanel()
 
     def get_active_document(self):
@@ -1069,12 +1081,21 @@ class Window(Gtk.Window):
         self.resize(300, 250)
         self.action_group = Gtk.ActionGroup(name='GeditMenu')
         self.action_group.add_actions([
-            ('Tools', None, _('_Tools'), None, None, None)])
+            ('File', None, _('_File'), None, None, None),
+            ('Edit', None, _('_Edit'), None, None, None),
+            ('View', None, _('_View'), None, None, None),
+            ('Search', None, _('_Search'), None, None, None),
+            ('Tools', None, _('_Tools'), None, None, None),
+            ])
         self.ui_manager = Gtk.UIManager()
         self.ui_manager.insert_action_group(self.action_group, -1)
         menu_xml = """
             <ui>
               <menubar name="MenuBar">
+                <menu name='FileMenu' action='File' />
+                <menu name='EditMenu' action='Edit' />
+                <menu name='ViewMenu' action='View' />
+                <menu name='SearchMenu' action='Search' />
                 <menu name='ToolsMenu' action='Tools' />
               </menubar>
             </ui>
@@ -1082,13 +1103,29 @@ class Window(Gtk.Window):
         self.ui_id = self.ui_manager.add_ui_from_string(menu_xml)
 
 
-__builtin__.__dict__['_'] = gettext
+GObject.signal_new(
+    'active-tab-changed', Window, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+GObject.signal_new(
+    'active-tab-state-changed', Window, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
 
 
 GObject.signal_new(
     'tab-added', Window, GObject.SIGNAL_RUN_LAST,
     GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
 
+
 GObject.signal_new(
-    'active-tab-changed', Window, GObject.SIGNAL_RUN_LAST,
+    'tab-removed', Window, GObject.SIGNAL_RUN_LAST,
     GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+GObject.signal_new(
+    'tab-reordered', Window, GObject.SIGNAL_RUN_LAST,
+    GObject.TYPE_NONE, (GObject.TYPE_PYOBJECT,))
+
+
+__builtin__.__dict__['_'] = gettext
